@@ -19,6 +19,8 @@ from ...ext import http
 from ...internal.logger import get_logger
 from ...pin import Pin
 from ...propagation.http import HTTPPropagator
+from ...utils import get_argument_value
+from ...utils.formats import asbool
 from ...utils.formats import deep_getattr
 from ...utils.formats import get_env
 from ...utils.wrappers import unwrap
@@ -36,8 +38,8 @@ log = get_logger(__name__)
 config._add(
     "botocore",
     {
-        "distributed_tracing": get_env("botocore", "distributed_tracing", default=True),
-        "invoke_with_legacy_context": get_env("botocore", "invoke_with_legacy_context", default=False),
+        "distributed_tracing": asbool(get_env("botocore", "distributed_tracing", default=True)),
+        "invoke_with_legacy_context": asbool(get_env("botocore", "invoke_with_legacy_context", default=False)),
     },
 )
 
@@ -129,7 +131,7 @@ def patched_api_call(original_func, instance, args, kwargs):
         span.set_tag(SPAN_MEASURED_KEY)
         operation = None
         if args:
-            operation = args[0]
+            operation = get_argument_value(args, kwargs, 0, "operation_name")
             # DEV: join is the fastest way of concatenating strings that is compatible
             # across Python versions (see
             # https://stackoverflow.com/questions/1316887/what-is-the-most-efficient-string-concatenation-method-in-python)
